@@ -144,7 +144,7 @@ def hapiopts():
 def hapi(*args, **kwargs):
     """Request data from a HAPI server.
 
-    Version: 0.2.2
+    Version: 0.2.4
 
 
     Examples
@@ -297,12 +297,12 @@ def hapi(*args, **kwargs):
     # Override defaults
     opts = setopts(hapiopts(), kwargs)
 
-    assert (opts['logging'] in [True, False])
-    assert (opts['cache'] in [True, False])
-    assert (opts['usecache'] in [True, False])
-    assert (opts['format'] in ['binary', 'csv'])
+    assert (opts['logging'] in [True, False]), "logging keyword must be True of False"
+    assert (opts['cache'] in [True, False]), "cache keyword must be True of False"
+    assert (opts['usecache'] in [True, False]), "usecache keyword must be True of False"
+    assert (opts['format'] in ['binary', 'csv']), "format keyword must be 'csv' or 'binary'"
     assert (opts['method'] in ['', 'pandas', 'numpy', 'pandasnolength', 'numpynolength'])
-    assert (opts['parallel'] in [True, False])
+    assert (opts['parallel'] in [True, False]), 'parallel keyword must be True or False'
     assert (isinstance(opts['n_parallel'], int) and opts['n_parallel'] > 1)
     assert (opts['n_chunks'] is None or isinstance(opts['n_chunks'], int) and opts['n_chunks'] > 0)
     assert (opts['dt_chunk'] in [None, 'infer', 'PT1H', 'P1D', 'P1M', 'P1Y'])
@@ -670,7 +670,10 @@ def hapi(*args, **kwargs):
                 toc0 = time.time() - tic0
                 log('Reading and parsing %s' % fnamebin.replace(urld + '/', ''), opts)
                 tic = time.time()
-                data = np.fromfile(fnamebin, dtype=dt)
+                try:
+                    data = np.fromfile(fnamebin, dtype=dt)
+                except:
+                    error('Could not read response from {}'.format(urlbin))
             else:
                 from io import BytesIO
                 log('Writing %s to buffer' % urlbin.replace(urld + '/', ''), opts)
@@ -679,7 +682,10 @@ def hapi(*args, **kwargs):
                 toc0 = time.time() - tic0
                 log('Parsing BytesIO buffer.', opts)
                 tic = time.time()
-                data = np.frombuffer(buff.read(), dtype=dt)
+                try:
+                    data = np.frombuffer(buff.read(), dtype=dt)
+                except:
+                    error('Could not read response from {}'.format(urlbin))
 
             # Handle Unicode
             time_name = meta['parameters'][0]['name']
@@ -934,7 +940,7 @@ def parse_missing_length(fnamecsv, dt, cols, psizes, pnames, ptypes, opts):
 
                 data[pnames[pn]] = tmp
 
-    if opts['method'] == 'pandas' or opts['method'] == 'pandasnolength':
+    if opts['method'] == '' or opts['method'] == 'pandas' or opts['method'] == 'pandasnolength':
         # If requested method was pandas, use pandasnolength method.
 
         # Read file into Pandas DataFrame
